@@ -94,9 +94,7 @@ class Cling(object):
             return self.method_not_allowed(environ, start_response)
         path_info = environ.get('PATH_INFO', '')
         full_path = self._full_path(path_info)
-        # guard against arbitrary file retrieval
-        if not (path.abspath(full_path) + '/')\
-               .startswith(path.abspath(self.root) + '/'):
+        if not self._is_under_root(full_path):
             return self.not_found(environ, start_response)
         if path.isdir(full_path):
             if full_path[-1] <> '/' or full_path == self.root:
@@ -128,12 +126,21 @@ class Cling(object):
             else:
                 return ['']
         except (IOError, OSError), e:
+            print e
             return self.not_found(environ, start_response)
 
     def _full_path(self, path_info):
         """Return the full path from which to read."""
         return self.root + path_info
 
+    def _is_under_root(self, full_path):
+        """Guard against arbitrary file retrieval."""
+        if (path.abspath(full_path) + path.sep)\
+            .startswith(path.abspath(self.root) + path.sep):
+            return True
+        else:
+            return False
+
     def _guess_type(self, full_path):
         """Guess the mime type using the mimetypes module."""
         return mimetypes.guess_type(full_path)[0] or 'text/plain'
